#[non_exhaustive]pub enum SectionWorkflowWarning {
PreservationMetadataUnavailable {
detail: String,
},
}Expand description
Non-fatal warning emitted while preparing a section export.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Preservation metadata could not be generated, so later preserving patch is unavailable until the section is re-exported successfully.
Implementations