#[non_exhaustive]pub struct HwpxStyle {
pub id: u32,
pub style_type: String,
pub name: String,
pub eng_name: String,
pub para_pr_id_ref: u32,
pub char_pr_id_ref: u32,
pub next_style_id_ref: u32,
pub lang_id: u32,
}Expand description
Resolved style definition from <hh:style>.
Stores style metadata like names and references to character/paragraph properties. This enables full roundtrip of style names like “바탕글”, “본문”, etc.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: u32Style ID (from id attribute).
style_type: StringStyle type (e.g. "PARA", "CHAR").
name: StringKorean style name (e.g. "바탕글").
eng_name: StringEnglish style name (e.g. "Normal").
para_pr_id_ref: u32Reference to paragraph properties (from paraPrIDRef).
char_pr_id_ref: u32Reference to character properties (from charPrIDRef).
next_style_id_ref: u32Reference to next style (from nextStyleIDRef).
lang_id: u32Language ID (from langID).